# fastui-chat

A minimalistic ChatBot Interface in pure python.

## How to use

```bash
> git clone https://github.com/shroominic/fastui-chat.git && cd fastui-chat

> ./dev-install.sh

> startapp
```

## TODO

- [ ] Stream AI Message

- [ ] Add model selection

- [ ] Store previous chats

- [ ] Use scrollview for chat

- [ ] ... add more todos
